Re: [PATCH 1/5]: Shorten statement for updating p

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



On 6/11/07, Gerrit Renker <gerrit@xxxxxxxxxxxxxx> wrote:
[CCID 3]: Shorten statement for updating p

This shortens the statement for updating the loss event
rate p when a feedback packet is received.

Signed-off-by: Gerrit Renker <gerrit@xxxxxxxxxxxxxx>
---
 net/dccp/ccids/ccid3.c |    7 ++-----
 1 file changed, 2 insertions(+), 5 deletions(-)

--- a/net/dccp/ccids/ccid3.c
+++ b/net/dccp/ccids/ccid3.c
@@ -436,12 +436,9 @@ static void ccid3_hc_tx_packet_recv(stru
                hctx->ccid3hctx_x_recv = opt_recv->ccid3or_receive_rate;
                hctx->ccid3hctx_x_recv <<= 6;

                /* Update loss event rate */
                pinv = opt_recv->ccid3or_loss_event_rate;
-               if (pinv == ~0U || pinv == 0)          /* see RFC 4342, 8.5   */
-                       hctx->ccid3hctx_p = 0;
-               else                                   /* can not exceed 100% */
-                       hctx->ccid3hctx_p = 1000000 / pinv;
+               hctx->ccid3hctx_p = (pinv == ~0U || pinv == 0)? 0 : scaled_div(1, pinv);

                /*
                 * Calculate new RTT sample and update moving average

I love '?:', but not when things get complex. I think this should be
kept as if+else.

I'll pick the conversion to scaled_div tho, looks right.

- Arnaldo
-
@@ -436,12 +436,9 @@ static void ccid3_hc_tx_packet_recv(stru
                hctx->ccid3hctx_x_recv <<= 6;

-               /* Update loss event rate */
+               /* Update loss event rate (scaled by 1e6), cf. RFC 4342, 8.5 */
                pinv = opt_recv->ccid3or_loss_event_rate;
To unsubscribe from this list: send the line "unsubscribe dccp" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html

[Index of Archives]     [Linux Kernel]     [IETF DCCP]     [Linux Networking]     [Git]     [Security]     [Linux Assembly]     [Bugtraq]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]

  Powered by Linux